@@ -3,10 +3,9 @@ import networkx as nx
 import numpy as np
 import pickle
 import logging
-import __init__
-from loggers import PrintLogger, FileLogger, multi_logger
+from .loggers import PrintLogger, FileLogger, multi_logger
 import os
-from graph_features import GraphFeatures
+from .features_infra.graph_features import GraphFeatures
 
 
 class FeatureCalculator:
